import { v4 as uuidv4 } from "uuid"

export type SimulationQuestion = {
  id: string
  question: string
  options: string[]
  correctAnswer: string
  explanation: string
  imageUrl?: string
}

export type Simulation = {
  id: string
  title: string
  description: string
  duration: number // en minutes
  questions: SimulationQuestion[]
}

const debutantSimulations: Simulation[] = [
  {
    id: uuidv4(),
    title: "Simulation débutant #1",
    description: "Première simulation pour les conducteurs débutants",
    duration: 20,
    questions: [
      {
        id: uuidv4(),
        question: "Quelle est la vitesse maximale autorisée en agglomération ?",
        options: ["30 km/h", "50 km/h", "70 km/h", "90 km/h"],
        correctAnswer: "50 km/h",
        explanation: "En agglomération, la vitesse est limitée à 50 km/h sauf indication contraire.",
      },
      {
        id: uuidv4(),
        question: "Que signifie un feu orange clignotant ?",
        options: [
          "Arrêt obligatoire",
          "Passage autorisé avec prudence",
          "Interdiction de passer",
          "Réservé aux transports en commun",
        ],
        correctAnswer: "Passage autorisé avec prudence",
        explanation:
          "Un feu orange clignotant indique un danger particulier. Vous pouvez passer mais avec une prudence accrue.",
      },
      {
        id: uuidv4(),
        question: "Quand le port de la ceinture de sécurité n'est-il pas obligatoire ?",
        options: [
          "En ville",
          "Sur autoroute",
          "Pour les personnes disposant d'un certificat médical d'exemption",
          "Pour les passagers arrière",
        ],
        correctAnswer: "Pour les personnes disposant d'un certificat médical d'exemption",
        explanation:
          "Le port de la ceinture est obligatoire sauf pour les personnes disposant d'un certificat médical d'exemption, les conducteurs en marche arrière, et certains professionnels lors de manœuvres à faible allure.",
      },
      {
        id: uuidv4(),
        question: "Que signifie un panneau de forme triangulaire avec un bord rouge ?",
        options: ["Une obligation", "Une interdiction", "Un danger", "Une indication"],
        correctAnswer: "Un danger",
        explanation:
          "Les panneaux triangulaires à bord rouge sont des panneaux de danger qui avertissent d'un danger potentiel à l'approche.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la distance minimale de sécurité à respecter sur autoroute par temps sec ?",
        options: ["1 mètre", "2 secondes", "50 mètres", "100 mètres"],
        correctAnswer: "2 secondes",
        explanation:
          "Sur autoroute, la distance de sécurité minimale correspond à 2 secondes de trajet, soit environ 70 mètres à 130 km/h par temps sec.",
      },
    ],
  },
  {
    id: uuidv4(),
    title: "Simulation débutant #2",
    description: "Deuxième simulation pour les conducteurs débutants",
    duration: 20,
    questions: [
      {
        id: uuidv4(),
        question: "Quelle est la durée de validité du permis probatoire ?",
        options: ["1 an", "2 ans", "3 ans", "5 ans"],
        correctAnswer: "3 ans",
        explanation:
          "Le permis probatoire est valable pendant 3 ans pour les conducteurs ayant suivi l'apprentissage anticipé de la conduite (AAC), et 2 ans pour les autres.",
      },
      {
        id: uuidv4(),
        question: "Quel est le taux d'alcoolémie maximum autorisé pour un conducteur novice ?",
        options: ["0,2 g/l", "0,5 g/l", "0,8 g/l", "1,0 g/l"],
        correctAnswer: "0,2 g/l",
        explanation:
          "Pour les conducteurs novices (permis probatoire), le taux d'alcoolémie maximum autorisé est de 0,2 g/l de sang, contre 0,5 g/l pour les conducteurs expérimentés.",
      },
      {
        id: uuidv4(),
        question: "Que signifie une ligne blanche continue sur la chaussée ?",
        options: [
          "Interdiction de dépasser",
          "Obligation de s'arrêter",
          "Zone de stationnement",
          "Voie réservée aux bus",
        ],
        correctAnswer: "Interdiction de dépasser",
        explanation:
          "Une ligne blanche continue signifie qu'il est interdit de la franchir ou de la chevaucher, donc interdit de dépasser ou de faire demi-tour en la franchissant.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle de priorité à un carrefour sans signalisation ?",
        options: [
          "Priorité à droite",
          "Priorité à gauche",
          "Priorité au véhicule le plus rapide",
          "Priorité au véhicule le plus lourd",
        ],
        correctAnswer: "Priorité à droite",
        explanation:
          "Dans un carrefour sans signalisation particulière, c'est la règle de la priorité à droite qui s'applique : vous devez céder le passage aux véhicules venant de votre droite.",
      },
      {
        id: uuidv4(),
        question: "Quand les feux de brouillard arrière peuvent-ils être utilisés ?",
        options: [
          "Par temps de pluie",
          "Par temps de neige",
          "Par brouillard épais uniquement",
          "La nuit pour être plus visible",
        ],
        correctAnswer: "Par brouillard épais uniquement",
        explanation:
          "Les feux de brouillard arrière ne doivent être utilisés que par brouillard épais ou chute de neige. Ils doivent être éteints dès que les conditions de visibilité redeviennent normales car ils sont très éblouissants.",
      },
    ],
  },
]

export default debutantSimulations
